@@ -70,12 +70,18 @@ fortify.matrix <- function(model, data = NULL, compat = FALSE, ...) {
 autoplot.matrix <- function (object, original = NULL, geom = 'tile',
                              colour = NULL, size = NULL, alpha = NULL,
                              fill = '#0000FF', shape = NULL,
-                             label = FALSE, label.label = 'rownames',
-                             label.colour = colour, label.alpha = NULL,
-                             label.size = NULL, label.angle = NULL,
-                             label.family = NULL, label.fontface = NULL,
+                             label = FALSE,
+                             label.label = 'rownames',
+                             label.colour = colour,
+                             label.alpha = NULL,
+                             label.size = NULL,
+                             label.angle = NULL,
+                             label.family = NULL,
+                             label.fontface = NULL,
                              label.lineheight = NULL,
-                             label.hjust = NULL, label.vjust = NULL,
+                             label.hjust = NULL,
+                             label.vjust = NULL,
+                             label.repel = FALSE,
                              scale = NULL,
                              xlim = c(NA, NA), ylim = c(NA, NA), log = "",
                              main = NULL, xlab = NULL, ylab = NULL, asp = NULL,
@@ -115,12 +121,19 @@ autoplot.matrix <- function (object, original = NULL, geom = 'tile',
       p <- p + geom_factory(geom_point, plot.data, colour = colour, size = size,
                             alpha = alpha, fill = fill, shape = shape)
     }
-    p <- plot_label(p = p, data = plot.data, label = label,
-                    label.label = label.label, label.colour = label.colour,
-                    label.alpha = label.alpha, label.size = label.size,
-                    label.angle = label.angle, label.family = label.family,
-                    label.fontface = label.fontface, label.lineheight = label.lineheight,
-                    label.hjust = label.hjust, label.vjust = label.vjust)
+    p <- plot_label(p = p, data = plot.data,
+                    label = label,
+                    label.label = label.label,
+                    label.colour = label.colour,
+                    label.alpha = label.alpha,
+                    label.size = label.size,
+                    label.angle = label.angle,
+                    label.family = label.family,
+                    label.fontface = label.fontface,
+                    label.lineheight = label.lineheight,
+                    label.hjust = label.hjust,
+                    label.vjust = label.vjust,
+                    label.repel = label.repel)
   } else {
     stop("Invalid geom is specified. Use 'tile' or 'point'.")
   }
